# Table of Contents

- [application-rationalization-track-report](<./application-rationalization-track-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Step 7: Track and Report](<./Step-7-Track-and-Report.md>)
  - [Use Application Rationalization Dashboard](<./Step-7-Track-and-Report/Use-Application-Rationalization-Dashboard.md>)
  - [Optional: Create a Custom Application Rationalization Dashboard](<./Step-7-Track-and-Report/Optional-Create-a-Custom-Application-Rationalization-Dashboard.md>)
  - [Configure the Architecture Executive Dashboard](<./Step-7-Track-and-Report/Configure-the-Architecture-Executive-Dashboard.md>)
  - [Was this page helpful?](<./Step-7-Track-and-Report/Was-this-page-helpful.md>)
